@@ -4,7 +4,7 @@ import random
 from pathlib import Path
 from datetime import datetime
 from typing import Any, Dict, Tuple, List
-from threading import Thread, Timer
+from threading import Timer
 
 try:
     import ujson as json
@@ -148,7 +148,8 @@ class Captcha(types.JsonDeserializable, types.JsonSerializable):
             now = datetime.now().timestamp()
             exec_at = self.date + self._timeout
             if now >= exec_at:
-                self._timeout_thread = Thread(target=CaptchaManager._handlers["on_timeout"], args=[self])
+                self._timeout_thread = Timer(interval=1, 
+                    function=CaptchaManager._handlers["on_timeout"], args=[self])
             else:
                 self._timeout_thread = Timer(interval=exec_at-now, 
                     function=CaptchaManager._handlers["on_timeout"], args=[self])
@@ -243,7 +244,7 @@ class CaptchaManager:
                 if f.endswith(".ttf") and not f.startswith("."):
                     _fonts.append(str(_fonts_path / f))
 
-        self.captchas = {}
+        self.captchas: Dict[str, Captcha] = {}
         if os.path.exists(_captcha_saves):
             saved_captchas = os.listdir(_captcha_saves)
             for f in saved_captchas:
@@ -347,7 +348,7 @@ class CaptchaManager:
             user_id = int(callback.data.split("=")[1])
             captcha_id = f"{self.__class__._bot_id}={callback.message.chat.id}={user_id}"
             if (captcha_id in self.captchas):
-                self._check_captcha(captcha_id)
+                self._check_captcha(self.captchas[captcha_id])
         else:
             captcha._update(bot, callback)
         
